% =========================================================================
%> @file  ProfileDataTiming.m
%> @author		Christian Campestrini (c.campestrini@tum.de)
%> @brief		Set of the timing data to find the constant charge and 
%>              discharge periods. This is an individual function.
%>
%> @date		08.06.2016
%>
%> @param		none
%>
%> @retval		ProfileTiming (index of start and end time)
%>
%> @syntax		ProfileTiming=ProfileDataTiming();
% =========================================================================
function ProfileTiming=ProfileDataTiming()
Temp={'n10','p00','p10','p25','p40'};
Test={'InitOk';'InitFail';'IOffset';'UOffset';'ROffset'};

%% CHANGE HERE
    % Load example data
    load('Example\RawData.mat');
    % Here the prepared information is transformed to the required data
    % format for every temperature. Due to the shifting in the fail case,
    % the timing is set for all test cases and a seperate timing for
    % profile A and A2
    for indexTemp=1:length(Temp)
        
        for iTest=1:length(Test)  

            if strcmp(Test{iTest},'InitFail')
                TimeOffsetEst=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis1(1);
                TimeOffsetRef=RawData.(Temp{indexTemp}).A.REF.Timing.Dis1(1);
            else
                TimeOffsetEst=0;
                TimeOffsetRef=0;
            end
            
            Start=RawData.(Temp{indexTemp}).A.BMS.Timing.Cha1(1);
            End=RawData.(Temp{indexTemp}).A.BMS.Timing.Cha1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A.EstTimeCha1=[Start, End];

            Start=RawData.(Temp{indexTemp}).A.REF.Timing.Cha1(1);
            End=RawData.(Temp{indexTemp}).A.REF.Timing.Cha1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A.RefTimeCha1=[Start, End];

            Start=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis1(1);
            End=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A.EstTimeDis1=[Start, End]-TimeOffsetEst;

            Start=RawData.(Temp{indexTemp}).A.REF.Timing.Dis1(1);
            End=RawData.(Temp{indexTemp}).A.REF.Timing.Dis1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A.RefTimeDis1=[Start, End]-TimeOffsetRef;

            Start=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis2(1);
            End=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis2(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A.EstTimeDis2=[Start, End]-TimeOffsetEst;

            Start=RawData.(Temp{indexTemp}).A.REF.Timing.Dis2(1);
            End=RawData.(Temp{indexTemp}).A.REF.Timing.Dis2(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A.RefTimeDis2=[Start, End]-TimeOffsetRef;   
            
            
            if strcmp(Test{iTest},'InitFail')
                TimeOffsetEst=RawData.(Temp{indexTemp}).A.BMS.Timing.Res1(1);
                TimeOffsetRef=RawData.(Temp{indexTemp}).A.REF.Timing.Res1(1);
            else
                TimeOffsetEst=0;
                TimeOffsetRef=0;
            end

            Start=RawData.(Temp{indexTemp}).A.BMS.Timing.Cha1(1);
            End=RawData.(Temp{indexTemp}).A.BMS.Timing.Cha1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A2.EstTimeCha1=[Start, End];

            Start=RawData.(Temp{indexTemp}).A.REF.Timing.Cha1(1);
            End=RawData.(Temp{indexTemp}).A.REF.Timing.Cha1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A2.RefTimeCha1=[Start, End];

            Start=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis1(1);
            End=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A2.EstTimeDis1=[Start, End]-TimeOffsetEst;

            Start=RawData.(Temp{indexTemp}).A.REF.Timing.Dis1(1);
            End=RawData.(Temp{indexTemp}).A.REF.Timing.Dis1(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A2.RefTimeDis1=[Start, End]-TimeOffsetRef;

            Start=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis2(1);
            End=RawData.(Temp{indexTemp}).A.BMS.Timing.Dis2(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A2.EstTimeDis2=[Start, End]-TimeOffsetEst;

            Start=RawData.(Temp{indexTemp}).A.REF.Timing.Dis2(1);
            End=RawData.(Temp{indexTemp}).A.REF.Timing.Dis2(end);
            ProfileTiming.(Test{iTest}).(Temp{indexTemp}).A2.RefTimeDis2=[Start, End]-TimeOffsetRef;
                            
        end
    end
end