% =========================================================================
%> @file  InputDataCheck.m
%> @author		Christian Campestrini (c.campestrini@tum.de)
%> @brief		check of the input data
%>
%> @date		08.06.2016
%>
%> @param		FilterResult (estimation result struct)
%>
%> @retval		none
%>
%> @syntax		InputDataCheck(FilterResult);
% =========================================================================
function InputDataCheck(FilterResult)

    warning off backtrace

    % Required data
    Temp={'n10';'p00';'p10';'p25';'p40';'xxx'};
    Test={'InitOk';'InitFail';'IOffset';'UOffset';'ROffset'};
    Data={'RefSOC','RefSOCBMS','EstSOC','EstTime','RefTime'};
    
    % Get fieldnames: data is checked for every algorithm
    Algo=fieldnames(FilterResult);

    %% Create Testmatrix with all required data fields
    clear TestMatrix
    for iAlgo=1:length(Algo)            
        TestMatrix.(Algo{iAlgo})=[];            
        for iTest=1:length(Test)  
            TestMatrix.(Algo{iAlgo}).(Test{iTest})=[];
            for iTemp=1:length(Temp)
                
                for iData=1:length(Data)
                    if strcmp(Temp{iTemp},'xxx')
                        if ~strcmp(Test{iTest},'InitFail')
                            TestMatrix.(Algo{iAlgo}).(Test{iTest}).(Temp{end}).C.(Data{iData})=[];    % For the case xxx the InitFail case not exists. For the variing temperature only Profile C exists 
                        end
                    else
                        TestMatrix.(Algo{iAlgo}).(Test{iTest}).(Temp{iTemp}).A.(Data{iData})=[];  % Profile A and B exist for all temperatures expect the variing one                        
                        TestMatrix.(Algo{iAlgo}).(Test{iTest}).(Temp{iTemp}).B.(Data{iData})=[];  

                        if strcmp(Test{iTest},'InitFail')
                            TestMatrix.(Algo{iAlgo}).InitFail.(Temp{iTemp}).A2.(Data{iData})=[]; % For the case InitFail case A2 exists.
                        end
                    end
                end
            end
        end
    end

    %% Compare the created TestMatrix with the input data
    clear Message
    % Loop for algorithms
    for iAlgo=1:length(Algo)  
        
        FieldNrTest=fieldnames(TestMatrix.(Algo{iAlgo}));
        % Loop for tests
        for iTest=1:length(FieldNrTest)  
            
            % warning if the test case not exists 
            if ~isfield(FilterResult.(Algo{iAlgo}),Test{iTest})
                Message=warning(['Test ' Test{iTest} ' is missing in ' Algo{iAlgo}]);
            else
                        
                FieldNrTemp=fieldnames(TestMatrix.(Algo{iAlgo}).(Test{iTest}));
                % Loop for temperature
                for iTemp=1:length(FieldNrTemp)

                    % warning if the temperature not exists 
                    if ~isfield(FilterResult.(Algo{iAlgo}).(Test{iTest}),Temp{iTemp})
                        Message=warning(['Temperature ' Temp{iTemp} ' is missing in ' Algo{iAlgo} ', ' Test{iTest}]);
                    else
                
                        FieldNrProfile=fieldnames(TestMatrix.(Algo{iAlgo}).(Test{iTest}).(Temp{iTemp}));
                        % Loop for profiles
                        for iProfile=1:length(FieldNrProfile)
                            
                            % warning if the profile not exists 
                            if ~isfield(FilterResult.(Algo{iAlgo}).(Test{iTest}).(Temp{iTemp}),FieldNrProfile{iProfile})
                                Message=warning(['Profile ' FieldNrProfile{iProfile} ' is missing in ' Algo{iAlgo} ', ' Test{iTest} ', ' Temp{iTemp}]);
                            else
                                %Loop for Data
                                for iData=1:length(Data)
                                    if ~isfield(FilterResult.(Algo{iAlgo}).(Test{iTest}).(Temp{iTemp}).(FieldNrProfile{iProfile}),(Data{iData}))
                                        Message=warning(['Data ' Data{iData} ' is missing in Profile ' FieldNrProfile{iProfile} ', ' Algo{iAlgo} ', ' Test{iTest} ', ' Temp{iTemp}]);     
                                    end
                                end                                   
                            end
                        end
                    end
                end
            end
        end
    end
    
    % Error if a warning is occured
    if exist('Message','var')
         error('Data is missing: Benchmark not possible!')
    else
        disp('Input data check is OK!')
    end
end